using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Grid.Grouping;

namespace F82248
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            this.gridGroupingControl1.TableOptions.AllowSelection = Syncfusion.Windows.Forms.Grid.GridSelectionFlags.None;
            this.gridGroupingControl1.TableOptions.ListBoxSelectionMode = SelectionMode.MultiExtended;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            DataSet dSet = new DataSet();

            //get the tables
            DataTable parentTable = GetParentTable();
            DataTable childTable = GetChildTable();
            DataTable grandChildTable = GetGrandChildTable();
            dSet.Tables.AddRange(new DataTable[] { parentTable, childTable, grandChildTable });

            //setup the relations
            DataColumn parentColumn = parentTable.Columns["parentID"];
            DataColumn childColumn = childTable.Columns["ParentID"];
            dSet.Relations.Add("ParentToChild", parentColumn, childColumn);
            

            parentColumn = childTable.Columns["childID"];
            childColumn = grandChildTable.Columns["ChildID"];
            dSet.Relations.Add("ChildToGrandChild", parentColumn, childColumn);

            // Register any DataTable/IList with SourceListSet, so that RelationDescriptor can resolve the name
            this.gridGroupingControl1.Engine.SourceListSet.Add("MyParentTable", parentTable);
            this.gridGroupingControl1.Engine.SourceListSet.Add("MyChildTable", childTable);
            this.gridGroupingControl1.Engine.SourceListSet.Add("MyGrandChildTable", grandChildTable);

            //dSet.Relations[0].Nested = true;
            //dSet.Relations[1].Nested = true;
            GridRelationDescriptor rd1 = new GridRelationDescriptor("ParentToChild");
            rd1.ChildTableName = "MyChildTable";
            rd1.RelationKind = Syncfusion.Grouping.RelationKind.RelatedMasterDetails;
            rd1.RelationKeys.Add("parentID", "ParentID");

            this.gridGroupingControl1.TableDescriptor.Relations.Add(rd1);

            GridRelationDescriptor rd2 = new GridRelationDescriptor("ChildToGrandChild");
            rd2.ChildTableName = "MyGrandChildTable";
            rd2.RelationKind = Syncfusion.Grouping.RelationKind.RelatedMasterDetails;
            rd2.RelationKeys.Add("childID", "ChildID");

            rd1.ChildTableDescriptor.Relations.Add(rd2);
          
            
            this.gridGroupingControl1.DataSource = parentTable; //master

            this.gridGroupingControl1.Table.SelectedRecordsChanged += new Syncfusion.Grouping.SelectedRecordsChangedEventHandler(Table_SelectedRecordsChanged);
        }

        void Table_SelectedRecordsChanged(object sender, Syncfusion.Grouping.SelectedRecordsChangedEventArgs e)
        {
            Console.WriteLine("Changed");
        }

        private int parentRows = 10;
        private int ChildRows = 30;
        private int GrandChildRows = 80;

        private DataTable GetParentTable()
        {
            DataTable dt = new DataTable("MyParentTable");

            dt.Columns.Add(new DataColumn("parentID")); //lower case p
            dt.Columns.Add(new DataColumn("ParentName"));

            for (int i = 0; i < parentRows; ++i)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i.ToString();
                dr[1] = string.Format("parentName{0}", i);
                dt.Rows.Add(dr);
            }
            return dt;
        }

        private Random r = new Random();

        private DataTable GetChildTable()
        {
            DataTable dt = new DataTable("MyChildTable");

            dt.Columns.Add(new DataColumn("childID")); //lower case c
            dt.Columns.Add(new DataColumn("Name"));
            dt.Columns.Add(new DataColumn("ParentID")); //upper case P

            for (int i = 0; i < ChildRows; ++i)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i.ToString();
                dr[1] = string.Format("ChildName{0}", i);
                dr[2] = r.Next(parentRows).ToString();//(i % parentRows).ToString();
                dt.Rows.Add(dr);
            }

            return dt;
        }

        private DataTable GetGrandChildTable()
        {
            DataTable dt = new DataTable("MyGrandChildTable");

            dt.Columns.Add(new DataColumn("GrandChildID"));
            dt.Columns.Add(new DataColumn("Name"));
            dt.Columns.Add(new DataColumn("ChildID")); //upper case C

            for (int i = 0; i < GrandChildRows; ++i)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i.ToString();
                dr[1] = string.Format("GrandChildName{0}", i);
                dr[2] = r.Next(ChildRows).ToString();//(i % ChildRows).ToString();
                dt.Rows.Add(dr);
            }

            return dt;
        }
    }
}